@@ -251,10 +251,11 @@ class Py3statusWrapper:
         """
         self.config = vars(options)
         self.i3bar_running = True
-        self.last_loop_ts = time.monotonic()
+        self.inhibit_signal_ts = time.monotonic()
         self.last_refresh_ts = time.monotonic()
         self.lock = Event()
         self.modules = {}
+        self.next_allowed_signal = SIGTSTP
         self.notified_messages = set()
         self.options = options
         self.output_modules = {}
@@ -540,6 +541,50 @@ class Py3statusWrapper:
                 msg = f'Loading module "{module}" failed ({err}).'
                 self.report_exception(msg, level="warning")
 
+    def _log_gitversion(self):
+        # A git repo is detected looking for the .git directory
+
+        git_path = Path(__file__).resolve().parent.parent / ".git"
+        if not git_path.exists():
+            return
+
+        self.log("Running within git repo")
+
+        try:
+            import git
+        except ImportError:
+            repo = None
+        else:
+            try:
+                repo = git.Repo(git_path.parent)
+            except Exception:
+                repo = None
+
+        if not repo:
+            try:
+                with (git_path / "HEAD").open() as f:
+                    out = f.readline()
+            except OSError:
+                self.log(
+                    "Unable to read git HEAD. "
+                    "Use python git package for more repo information"
+                )
+                return
+            branch = "/".join(out.strip().split("/")[2:])
+            self.log(f"git branch: {branch}")
+            # last commit
+            log_path = git_path / "logs" / "refs" / "heads" / branch
+            with log_path.open() as f:
+                out = f.readlines()[-1]
+            sha = out.split(" ")[1][:7]
+            msg = ":".join(out.strip().split("\t")[-1].split(":")[1:])
+            self.log(f"git commit: {sha}{msg}")
+        else:
+            commit = repo.head.commit
+            self.log(f"git branch: {repo.active_branch.name}")
+            self.log(f"git commit: {commit.hexsha[:7]} {commit.summary}")
+            self.log(f"git clean: {not repo.is_dirty()!s}")
+
     def setup(self):
         """
         Setup py3status and spawn i3status/events/modules threads.
@@ -550,24 +595,8 @@ class Py3statusWrapper:
         msg = "Starting py3status version {version} python {python_version}"
         self.log(msg.format(**self.config))
 
-        try:
-            # if running from git then log the branch and last commit
-            # we do this by looking in the .git directory
-            git_path = Path(__file__).resolve().parent.parent / ".git"
-            # branch
-            with (git_path / "HEAD").open() as f:
-                out = f.readline()
-            branch = "/".join(out.strip().split("/")[2:])
-            self.log(f"git branch: {branch}")
-            # last commit
-            log_path = git_path / "logs" / "refs" / "heads" / branch
-            with log_path.open() as f:
-                out = f.readlines()[-1]
-            sha = out.split(" ")[1][:7]
-            msg = ":".join(out.strip().split("\t")[-1].split(":")[1:])
-            self.log(f"git commit: {sha}{msg}")
-        except:  # noqa e722
-            pass
+        # if running from git then log the branch and last commit
+        self._log_gitversion()
 
         self.log("window manager: {}".format(self.config["wm_name"]))
 
@@ -990,20 +1019,32 @@ class Py3statusWrapper:
         return ",".join(dumps(x) for x in outputs)
 
     def i3bar_stop(self, signum, frame):
-        if time.monotonic() - self.last_loop_ts < 1:
+        if (
+            self.next_allowed_signal == signum
+            and time.monotonic() > self.inhibit_signal_ts
+        ):
             self.log(f"received stop_signal {Signals(signum).name}")
             self.i3bar_running = False
             # i3status should be stopped
             self.i3status_thread.suspend_i3status()
             self.sleep_modules()
+            self.next_allowed_signal = SIGCONT
         else:
             self.log(f"inhibited stop_signal {Signals(signum).name}", level="warning")
+            self.inhibit_signal_ts = time.monotonic() + 0.1
 
     def i3bar_start(self, signum, frame):
-        self.log(f"received resume signal {Signals(signum).name}")
-        self.last_loop_ts = time.monotonic()
-        self.i3bar_running = True
-        self.wake_modules()
+        if (
+            self.next_allowed_signal == signum
+            and time.monotonic() > self.inhibit_signal_ts
+        ):
+            self.log(f"received resume signal {Signals(signum).name}")
+            self.i3bar_running = True
+            self.wake_modules()
+            self.next_allowed_signal = self.stop_signal
+        else:
+            self.log(f"inhibited start_signal {Signals(signum).name}", level="warning")
+            self.inhibit_signal_ts = time.monotonic() + 0.1
 
     def sleep_modules(self):
         # Put all py3modules to sleep so they stop updating
@@ -1074,8 +1115,6 @@ class Py3statusWrapper:
             while not self.i3bar_running:
                 time.sleep(0.1)
 
-            self.last_loop_ts = time.monotonic()
-
             # check if an update is needed
             if self.update_queue:
                 while len(self.update_queue):
